@@ -7,8 +7,8 @@ def test_pristine_lfs_simple_checkout(fake_pristine_lfs):
 
     do_checkout('pristine-lfs', tarball=tarball.name, outdir=outdir)
     assert len(list(outdir.glob('**'))) == 1, list(outdir.glob('**'))
-    assert (outdir / tarball.name).is_file()
-    assert (outdir / tarball.name).stat().st_size == size
+    assert (outdir / tarball.name).is_file(), 'Extracted tarball not found'
+    assert (outdir / tarball.name).stat().st_size == size, 'Extracted tarball of a wrong size'
 
 
 def test_pristine_lfs_auto_checkout(test_git_repo):
@@ -24,7 +24,7 @@ def test_pristine_lfs_auto_checkout(test_git_repo):
 
     do_checkout('pristine-lfs', tarball=None, outdir=outdir)
     assert len(list(outdir.glob('**'))) == 1, list(outdir.glob('**'))
-    assert (outdir / tarball.name).is_file()
-    assert (outdir / tarball.name).stat().st_size == size
+    assert (outdir / tarball.name).is_file(), 'Extracted tarball not found'
+    assert (outdir / tarball.name).stat().st_size == size, 'Extracted tarball of a wrong size'
 
 
