@@ -3,7 +3,7 @@ from textwrap import dedent
 from pristine_lfs import do_import, do_list
 
 
-def test_pristine_lfs_import_dsc(fake_tarball, capsys):
+def test_pristine_lfs_import_dsc(fake_tarball):
     repo, tarball, size, sha = fake_tarball
 
     base, *_ = tarball.name.split('.')
@@ -35,11 +35,9 @@ def test_pristine_lfs_import_dsc(fake_tarball, capsys):
     do_import(dsc.open(), 'pristine-lfs', f'import {package}')
     do_import(dsc.open(), 'pristine-lfs-source', f'import {package}', full=True)
 
-    do_list(branch='pristine-lfs')
-    captured = capsys.readouterr()
-    assert ['true_0.orig.tar.gz'] == captured.out.splitlines()
+    ret = list(do_list(branch='pristine-lfs'))
+    assert ['true_0.orig.tar.gz'] == ret
 
-    do_list(branch='pristine-lfs-source')
-    captured = capsys.readouterr()
-    assert ['true_0.dsc', 'true_0.orig.tar.gz'] == captured.out.splitlines()
+    ret = list(do_list(branch='pristine-lfs-source'))
+    assert ['true_0.dsc', 'true_0.orig.tar.gz'] == ret
 
